package jalview.util.matcher;

import java.util.function.Function;

/**
 * An interface for an object that can apply one or more match conditions, given
 * a key-value provider. The match conditions are stored against key values, and
 * applied to the value obtained by a key-value lookup.
 * 
 * @author gmcarstairs
 */
public interface KeyedMatcherI
{
  /**
   * Answers true if the value provided for this matcher's key passes this
   * matcher's match condition
   * 
   * @param valueProvider
   * @return
   */
  boolean matches(Function<String, String> valueProvider);

  /**
   * Answers the value key this matcher operates on
   * 
   * @return
   */
  String getKey();

  /**
   * Answers the match condition that is applied
   * 
   * @return
   */
  MatcherI getMatcher();
}
